@@ -1,10 +1,9 @@
 use glium::glutin::event_loop::EventLoopProxy;
 use image::io::Reader as ImageReader;
-use image::{ImageBuffer, ImageFormat, Rgba, Frame, codecs::gif::GifDecoder, AnimationDecoder};
-use libwebp::WebPDecodeRGBA;
+use image::{ImageBuffer, ImageFormat, Rgba, Frame, codecs::gif::GifDecoder, AnimationDecoder, Delay};
 use psd::Psd;
-use std::{fs, io::Cursor, path::Path, thread, time::Instant};
 use usvg::{fontdb::Database, FitTo, Options, Tree};
+use std::{fs, io::Cursor, path::Path, thread, time::{Instant, Duration}};
 
 use super::super::UserEvent;
 
@@ -25,17 +24,17 @@ pub fn load_image(proxy: EventLoopProxy<UserEvent>, path: impl AsRef<Path>) {
         };
 
         if let Some(image) = load_raster(&bytes) {
-            let _ = proxy.send_event(UserEvent::ImageLoaded(image, path_buf, start));
+            let _ = proxy.send_event(UserEvent::ImageLoaded(Some(image), Some(path_buf), start));
             return;
         }
         
         if let Some(image) = load_svg(&bytes) {
-            let _ = proxy.send_event(UserEvent::ImageLoaded(vec![Frame::new(image)], path_buf, start));
+            let _ = proxy.send_event(UserEvent::ImageLoaded(Some(vec![Frame::new(image)]), Some(path_buf), start));
             return;
         }
 
         if let Some(image) = load_psd(&bytes) {
-            let _ = proxy.send_event(UserEvent::ImageLoaded(vec![Frame::new(image)], path_buf, start));
+            let _ = proxy.send_event(UserEvent::ImageLoaded(Some(vec![Frame::new(image)]), Some(path_buf), start));
             return;
         }
 
@@ -63,16 +62,26 @@ fn load_raster(bytes: &[u8]) -> Option<Vec<Frame>> {
             None
         },
         ImageFormat::WebP => {
-            match WebPDecodeRGBA(bytes) {
-                Ok((width, height, buf)) => {
-                    if let Some(image) = ImageBuffer::<Rgba<u8>, Vec<u8>>::from_raw(width, height, buf.to_vec()) {
-                        Some(vec![Frame::new(image)])
+            if let Ok(decoder) = webp_animation::Decoder::new(bytes) {
+                let mut time = 0;
+                let frames: Vec<Frame> = decoder.into_iter().filter_map(|frame| {
+                    let timestamp = frame.timestamp();
+                    let difference =  timestamp - time;
+                    
+                    if let Ok(image) = frame.into_image() {
+                        time = timestamp;
+                        let delay = Delay::from_saturating_duration(Duration::from_millis(difference as u64));
+                        Some(Frame::from_parts(image, 0, 0, delay))
                     } else {
                         None
                     }
+                }).collect();
+                
+                if frames.len() > 0 {
+                    return Some(frames)
                 }
-                Err(_) => None,
             }
+            None
         },
         format => {
             match ImageReader::with_format(Cursor::new(&bytes), format).decode() {
